Responsive class

Constructors

Responsive(BuildContext context)

Properties

context → BuildContext
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenWidth → ScreenWidth
no setter

Methods

getActiveBreakpoint() → Breakpoints
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
value<ValueType>(Map<Breakpoints, ValueType> value) → ValueType

Operators

operator ==(Object other) → bool
The equality operator.
inherited